Module concurrent

Module concurrent 

Concurrent keyspace using DashMap for lock-free multi-threaded access.

This is an alternative to the sharded architecture that eliminates channel overhead by allowing direct access from multiple connection handlers.

Structs

ConcurrentKeyspace
A concurrent keyspace backed by DashMap.

Enums

ConcurrentFloatError
Errors from float operations on the concurrent keyspace.
ConcurrentOpError
Errors from integer/float operations on the concurrent keyspace.