is_large_value

Function is_large_value 

pub fn is_large_value(value: &Value) -> bool
Returns true if dropping this value is expensive enough to justify sending it to the background drop thread.

Strings are always cheap to drop (reference-counted Bytes). Collections are considered large when they exceed LAZY_FREE_THRESHOLD elements.