pub struct PreparedShard { /* private fields */ }Expand description
Everything needed to run a shard on a specific runtime.
Created by prepare_shard without spawning any tasks. The caller
is responsible for passing this to run_prepared on the desired
tokio runtime — this is the hook that enables thread-per-core
deployment where each worker thread runs its own shard.