Concurrent keyspace using DashMap for lock-free multi-threaded access.
This is an alternative to the sharded architecture that eliminates channel overhead by allowing direct access from multiple connection handlers.
Structs
- Concurrent
Keyspace - A concurrent keyspace backed by DashMap.
Enums
- Concurrent
Float Error - Errors from float operations on the concurrent keyspace.
- Concurrent
OpError - Errors from integer/float operations on the concurrent keyspace.